changeset 18132:306c5fc49ed1 draft

(svn r22957) -Codechange: SPECSTR_PLAYERNAME is actually the company name, which is derived from the town name + ' Transport'. So make sure the last constant is in sync with the town name table
author rubidium <rubidium@openttd.org>
date Fri, 23 Sep 2011 19:27:15 +0000
parents 07ea0c5b88b8
children 3e2f202d2981
files src/company_cmd.cpp src/saveload/strings_sl.cpp src/strings_type.h
diffstat 3 files changed, 7 insertions(+), 12 deletions(-) [+]
line wrap: on
line diff
--- a/src/company_cmd.cpp
+++ b/src/company_cmd.cpp
@@ -349,7 +349,7 @@
 	StringID str;
 	uint32 strp;
 	if (t->name == NULL && IsInsideMM(t->townnametype, SPECSTR_TOWNNAME_START, SPECSTR_TOWNNAME_LAST + 1)) {
-		str = t->townnametype - SPECSTR_TOWNNAME_START + SPECSTR_PLAYERNAME_START;
+		str = t->townnametype - SPECSTR_TOWNNAME_START + SPECSTR_COMPANY_NAME_START;
 		strp = t->townnameparts;
 
 verify_name:;
--- a/src/saveload/strings_sl.cpp
+++ b/src/saveload/strings_sl.cpp
@@ -29,8 +29,8 @@
 	switch (s) {
 		case 0x0006: return STR_SV_EMPTY;
 		case 0x7000: return STR_SV_UNNAMED;
-		case 0x70E4: return SPECSTR_PLAYERNAME_ENGLISH;
-		case 0x70E9: return SPECSTR_PLAYERNAME_ENGLISH;
+		case 0x70E4: return SPECSTR_COMPANY_NAME_START;
+		case 0x70E9: return SPECSTR_COMPANY_NAME_START;
 		case 0x8864: return STR_SV_TRAIN_NAME;
 		case 0x902B: return STR_SV_ROAD_VEHICLE_NAME;
 		case 0x9830: return STR_SV_SHIP_NAME;
--- a/src/strings_type.h
+++ b/src/strings_type.h
@@ -54,16 +54,11 @@
 	SPECSTR_TOWNNAME_CATALAN,
 	SPECSTR_TOWNNAME_LAST      = SPECSTR_TOWNNAME_CATALAN,
 
-	/* special strings for player names on the form "TownName transport". */
-	SPECSTR_PLAYERNAME_START   = 0x70EA,
-	SPECSTR_PLAYERNAME_ENGLISH = SPECSTR_PLAYERNAME_START,
-	SPECSTR_PLAYERNAME_FRENCH,
-	SPECSTR_PLAYERNAME_GERMAN,
-	SPECSTR_PLAYERNAME_AMERICAN,
-	SPECSTR_PLAYERNAME_LATIN,
-	SPECSTR_PLAYERNAME_SILLY,
-	SPECSTR_PLAYERNAME_LAST    = SPECSTR_PLAYERNAME_SILLY,
+	/* special strings for company names on the form "TownName transport". */
+	SPECSTR_COMPANY_NAME_START = 0x70EA,
+	SPECSTR_COMPANY_NAME_LAST  = SPECSTR_COMPANY_NAME_START + SPECSTR_TOWNNAME_LAST - SPECSTR_TOWNNAME_START,
 
+	SPECSTR_SILLY_NAME         = 0x70E5,
 	SPECSTR_ANDCO_NAME         = 0x70E6,
 	SPECSTR_PRESIDENT_NAME     = 0x70E7,